@@ -1,11 +1,11 @@
 # -*- perl -*-
 ##----------------------------------------------------------------------------
 ## REST API Framework - ~/lib/Net/API/REST/Request.pm
-## Version v0.8.4
+## Version v0.8.6
 ## Copyright(c) 2020 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <@sitael.tokyo.deguest.jp>
 ## Created 2019/09/01
-## Modified 2020/05/16
+## Modified 2020/06/13
 ## 
 ##----------------------------------------------------------------------------
 package Net::API::REST::Request;
@@ -40,7 +40,7 @@ BEGIN
     use JSON;
     use Nice::Try;
     use version;
-    our $VERSION = 'v0.8.4';
+    our $VERSION = 'v0.8.6';
     our @DoW = qw( Sun Mon Tue Wed Thu Fri Sat );
     our @MoY = qw( Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec );
     our $MoY = {};
@@ -140,6 +140,8 @@ sub accept_language { return( shift->headers->{ 'Accept-Language' } ); }
 ## The allowed methods, GET, POST, PUT, OPTIONS, HEAD, etc
 sub allowed { return( shift->_try( 'request', 'allowed', @_ ) ); }
 
+sub args { return( shift->_try( 'request', 'args', @_ ) ); }
+
 sub as_string { return( shift->_try( 'request', 'as_string' ) ); }
 
 sub auth { return( shift->_set_get_scalar( 'auth', @_ ) ); }
@@ -1052,7 +1054,7 @@ sub _try
     my $pack = shift( @_ ) || return( $self->error( "No Apache package name was provided to call method" ) );
     my $meth = shift( @_ ) || return( $self->error( "No method name was provided to try!" ) );
     my $r = Apache2::RequestUtil->request;
-    $r->log_error( "Net::API::REST::Request::_try to call method \"$meth\" in package \"$pack\"." );
+    # $r->log_error( "Net::API::REST::Request::_try to call method \"$meth\" in package \"$pack\"." );
     try
     {
         return( $self->$pack->$meth ) if( !scalar( @_ ) );
@@ -1064,6 +1066,61 @@ sub _try
     }
 }
 
+## URI::Query version 0.16 is not dealing with utf8 strings properly, so I am overwriting some part here to decode utf8
+package URI::Query;
+no warnings 'redefine'; 
+sub _parse_qs
+{
+    my $self = shift( @_ );
+    my $qs = shift( @_ );
+    for( split( /[&;]/, $qs ) )
+    {
+        my( $key, $value ) = map{ URI::Escape::uri_unescape( $_ ) } split( /=/, $_, 2 );
+        $key = Encode::decode_utf8( $key ) if( !Encode::is_utf8( $key ) );
+        $value = Encode::decode_utf8( $value ) if( !Encode::is_utf8( $value ) );
+        $self->{qq}->{$key} ||= [];
+        push( @{$self->{qq}->{$key}}, $value ) if( defined( $value ) && $value ne '' );
+    }
+    $self
+}
+
+sub _init_from_arrayref
+{
+    my( $self, $arrayref ) = @_;
+    while( @$arrayref )
+    {
+        my $key   = shift( @$arrayref );
+        my $value = shift( @$arrayref );
+        my $key_unesc = URI::Escape::uri_unescape( $key );
+        $key_unesc = Encode::decode_utf8( $key_unesc ) if( !Encode::is_utf8( $key_unesc ) );
+
+        $self->{qq}->{$key_unesc} ||= [];
+        if( defined( $value ) && $value ne '' )
+        {
+            my @values;
+            if( !ref( $value ) )
+            {
+                @values = split( "\0", $value );
+            }
+            elsif( ref( $value ) eq 'ARRAY' )
+            {
+                @values = @$value;
+            }
+            else
+            {
+                die( "Invalid value found: $value. Not string or arrayref!" );
+            }
+            # push @{$self->{qq}->{$key_unesc}}, map { uri_unescape($_) } @values;
+            for( @values )
+            {
+                $_ = URI::Escape::uri_unescape( $_ );
+                $_ = UTF::decode_utf8( $_ ) if( !Encode::is_utf8( $_ ) );
+                push( @{$self->{qq}->{$key_unesc}}, $_ );
+            }
+        }
+    }
+}
+
 1;
 
 __END__
@@ -1084,7 +1141,7 @@ Net::API::REST::Request - Apache2 Incoming Request Access and Manipulation
 
 =head1 VERSION
 
-    v0.8.4
+    v0.8.6
 
 =head1 DESCRIPTION
 
